@@ -15,6 +15,8 @@
 #  License along with this library.
 import argparse
 import asyncio
+import os
+
 import sys
 import aiohttp
 
@@ -43,26 +45,65 @@ async def _handle_package_manager_command(starting_args,
     LOGGER = logging.get_logger(f"{octobot_tentacles_manager.PROJECT_NAME}-CLI")
     async with aiohttp.ClientSession() as aiohttp_session:
         include_dev_mode = starting_args.include_dev_mode
+        include_tentacles_export = starting_args.include_tentacles_export
         if starting_args.creator:
             error_count = api.start_tentacle_creator({}, starting_args.creator)
         elif starting_args.repair:
             error_count = await api.repair_installation(bot_path=target_dir)
         elif starting_args.export:
-            error_count = await api.create_tentacles_package(export_tentacles_output, target_dir,
+            error_count = await api.create_tentacles_package(export_tentacles_output,
+                                                             target_dir,
                                                              exported_tentacles_package=exported_tentacles_package,
-                                                             in_zip=False, with_dev_mode=include_dev_mode,
+                                                             in_zip=False,
+                                                             with_dev_mode=include_dev_mode,
+                                                             upload_details=starting_args.upload_package_export,
                                                              cythonize=cythonize)
+            if include_tentacles_export:
+                error_count += await api.create_all_tentacles_bundle(
+                    output_dir=export_tentacles_output,
+                    tentacles_folder=target_dir,
+                    exported_tentacles_package=exported_tentacles_package,
+                    in_zip=False,
+                    should_remove_artifacts_after_use=True,
+                    upload_url=starting_args.upload_tentacles_export[0]
+                    if len(starting_args.upload_tentacles_export) > 0 else None,
+                    with_dev_mode=include_dev_mode,
+                    cythonize=cythonize)
         elif starting_args.pack:
-            error_count = await api.create_tentacles_package(packed_tentacles_output, target_dir,
+            error_count = await api.create_tentacles_package(packed_tentacles_output,
+                                                             target_dir,
                                                              exported_tentacles_package=exported_tentacles_package,
-                                                             in_zip=True, with_dev_mode=include_dev_mode,
+                                                             in_zip=True,
+                                                             with_dev_mode=include_dev_mode,
+                                                             upload_details=starting_args.upload_package_export,
                                                              cythonize=cythonize)
+            if include_tentacles_export:
+                error_count += await api.create_all_tentacles_bundle(
+                    output_dir=export_tentacles_output,
+                    tentacles_folder=target_dir,
+                    exported_tentacles_package=exported_tentacles_package,
+                    in_zip=True,
+                    with_dev_mode=include_dev_mode,
+                    should_remove_artifacts_after_use=True,
+                    upload_url=starting_args.upload_tentacles_export[0]
+                    if len(starting_args.upload_tentacles_export) > 0 else None,
+                    cythonize=cythonize)
         elif single_tentacle_path:
             error_count = await api.install_single_tentacle(single_tentacle_path,
                                                             single_tentacle_type,
                                                             bot_path=target_dir,
                                                             aiohttp_session=aiohttp_session,
                                                             bot_install_dir=bot_install_dir)
+        elif starting_args.nexus_upload:
+            if 2 <= len(starting_args.nexus_upload) <= 3:
+                file_or_folder_path = starting_args.nexus_upload[1]
+                file_or_folder_alias = starting_args.nexus_upload[2] if len(starting_args.nexus_upload) == 3 else None
+                error_count += await api.upload_file_or_folder_to_nexus(nexus_path=starting_args.nexus_upload[0],
+                                                                        artifact_path=file_or_folder_path,
+                                                                        artifact_alias=file_or_folder_alias)
+            else:
+                raise Exception("Missing arguments. Usage : <nexus_path> <file_or_folder_path> [file_or_folder_alias].")
+
         elif not (starting_args.all or starting_args.tentacle_names):
             LOGGER.error("Please provide at least one tentacle name or add the '--all' parameter")
             return 1
@@ -110,6 +151,7 @@ async def _handle_package_manager_command(starting_args,
                                                              bot_path=target_dir,
                                                              use_confirm_prompt=starting_args.force,
                                                              quite_mode=quite_mode)
+
     if error_count > 0:
         LOGGER.error(f"{error_count} errors occurred while processing tentacles.")
         return 1
@@ -184,11 +226,25 @@ def register_tentacles_manager_arguments(tentacles_parser) -> None:
     tentacles_parser.add_argument("-f", "--force", help="Skip user confirmations.", action='store_true')
     tentacles_parser.add_argument("-idm", "--include-dev-mode", help="Include tentacles in dev mode in export and "
                                                                      "pack commands.", action='store_true')
+    tentacles_parser.add_argument("-ite", "--include-tentacles-export", help="Include tentacles during export and "
+                                                                             "pack commands.", action='store_true')
+    tentacles_parser.add_argument("-ute", "--upload-tentacles-export", help="Upload tentacles during export and "
+                                                                            "pack commands. Usage: <nexus_path>",
+                                  nargs=1)
+    tentacles_parser.add_argument("-upe", "--upload-package-export", help="Upload package during export and "
+                                                                          "pack commands. "
+                                                                          "Usage: <nexus_path> [package_alias]",
+                                  nargs='+')
     tentacles_parser.add_argument("-c", "--creator", help="Start OctoBot Tentacles Creator.\n Examples: -c Evaluator "
                                                           "to create a new evaluator tentacles. Use: -c help to get the"
                                                           " Tentacle Creator help.", nargs='+')
     tentacles_parser.add_argument("-cy", "--cythonize", help="Option for the --pack command: cythonize and "
                                                              "compile the packed tentacles.", action='store_true')
+    tentacles_parser.add_argument("-nu", "--nexus-upload", help="Upload a file or files of folder to nexus at path."
+                                                                "Usage : <nexus_path> <file_or_folder_path> "
+                                                                "[file_or_folder_alias]"
+                                                                "Example : officials/base/ 0.4.0.zip",
+                                  nargs='+')
     tentacles_parser.add_argument("-q", "--quite", help="Only display errors in logs.", action='store_true')
     tentacles_parser.add_argument("tentacle_names", nargs="*")
 
