@@ -43,6 +43,16 @@ METADATA_DEV_MODE = "dev_mode"
 METADATA_TENTACLES_REQUIREMENTS = "tentacles-requirements"
 METADATA_TENTACLES_GROUP = "tentacles_group"
 
+# Artifact metadata
+ARTIFACT_METADATA_FILE = "metadata.yaml"
+ARTIFACT_METADATA_VERSION = "version"
+ARTIFACT_METADATA_NAME = "name"
+ARTIFACT_METADATA_ARTIFACT_TYPE = "type"
+ARTIFACT_METADATA_REPOSITORY = "repository"
+ARTIFACT_METADATA_AUTHOR = "author"
+ARTIFACT_METADATA_ARTIFACTS = "artifacts"
+DEFAULT_ARTIFACT_METADATA_AUTHOR = "DrakkarSoftware"
+
 # Requirements
 TENTACLE_REQUIREMENT_VERSION_EQUALS = "=="
 
@@ -63,6 +73,13 @@ UNKNOWN_REPOSITORY_LOCATION = "Unknown repository location"
 
 # Tentacles packages
 UNKNOWN_TENTACLES_PACKAGE_LOCATION = "Unknown package location"
+TENTACLES_PACKAGE_PROFILES_PATH = "profiles"
+
+# exporter
+DEFAULT_EXPORT_DIR = "output"
+
+# Artifacts
+UNKNOWN_ARTIFACT_VERSION = "unknown_version"
 
 # Tentacles installation folders
 TENTACLES_INSTALL_TEMP_DIR = "temp_tentacles"
@@ -175,4 +192,4 @@ PLATFORM_TO_DOWNLOAD_PATH = {
     enums.PlatformsName.WINDOWS: "windows",
     enums.PlatformsName.LINUX: "linux",
     enums.PlatformsName.MAC: "macos",
-}
\ No newline at end of file
+}
